from django.db import models
from django.forms import ModelForm, DateField, ChoiceField, RadioSelect, BooleanField
from django.contrib.admin.widgets import AdminDateWidget
from django.utils.html import format_html

from .models import Project, Volunteer, IFG, Library, TYPE_CHOICES
from .settings import DATAPROTECTION, FOERDERRICHTLINIEN


class ProjectForm(ModelForm):

    start = DateField(widget=AdminDateWidget)

    class Meta:
        model = Project
        # fields = '__all__'
        exclude = ('pid',)

class VolunteerForm(ModelForm):

    choice = ChoiceField(choices=TYPE_CHOICES, widget=RadioSelect,
                         label='Was möchtest Du beantragen?')

    check = BooleanField(required=True,
                         label=format_html("Ich stimme den <a href='{}'>Datenschutzbestimmungen</a> und den <a href='{}'>Förderrichtlinen</a> zu",
                         DATAPROTECTION, FOERDERRICHTLINIEN))

    class Meta:
        model = Volunteer
        exclude = ('granted',)

class LibraryForm(ModelForm):

    class Meta:
        model = Library
        exclude = ('realname', 'email', 'username', 'type', 'granted')

class IFGForm(ModelForm):
    class Meta:
        model = IFG
        exclude = ('realname', 'email', 'username')
